<?php
/**
 *
 * Slideshow for Header extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2017 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\SlideWeUni\acp;

/**
* @package acp
*/
class acp_slideweuni_module
{
    var $u_action;
    var $new_config = array();

    function main($id, $mode)
    {
        global $config, $request, $user, $phpbb_container, $template, $phpbb_root_path;

        $action = $request->variable('action', '');
        $submit = (isset($_POST['submit'])) ? true : false;

        $form_key = 'acp_slide';
        add_form_key($form_key);
        /**
        *   Validation types are:
        *       string, int, bool,
        *       script_path (absolute path in url - beginning with / and no trailing slash),
        *       rpath (relative), rwpath (realtive, writable), path (relative path, but able to escape the root), wpath (writable)
        */
        $display_vars = array(
            'title' => 'ACP_SLIDE_WEUNI',
            'vars'  => array(
                'legend'                    => 'GENERAL_OPTIONS',
                'slide_weuni_active'        => array('lang' => 'L_SLIDE_WEUNI_ACTIVE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true),
                'slide_weuni_delay'         => array('lang' => 'L_SLIDE_WEUNI_DELAY', 'validate' => 'int:1000:20000', 'type' => 'number:0:99999', 'explain' => true, 'append' => ' ' . $user->lang('L_UNI_DELAY')),
                'slide_weuni_effect'        => array('lang' => 'L_SLIDE_WEUNI_EFFECT', 'validate' => 'int', 'type' => false, 'method' => false, 'explain' => false),
                'slide_weuni_title'         => array('lang' => 'L_SLIDE_WEUNI_TITLE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                'slide_weuni_color_tit_f'   => array('lang' => 'L_SLIDE_WEUNI_COLOR_TIT_F', 'validate' => 'string', 'type' => 'text:7:7', 'explain' => true),
                'slide_weuni_color_tit_b'   => array('lang' => 'L_SLIDE_WEUNI_COLOR_TIT_B', 'validate' => 'string', 'type' => 'text:7:7', 'explain' => true),
                'slide_weuni_search'        => array('lang' => 'L_SLIDE_WEUNI_SEARCH', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                'slide_weuni_controls'      => array('lang' => 'L_SLIDE_WEUNI_CONTROLS', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                'slide_weuni_aleatory'      => array('lang' => 'L_SLIDE_WEUNI_ALEATORY', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                'slide_weuni_cant_img'      => array('lang' => 'L_SLIDE_WEUNI_CANT_IMG', 'validate' => 'int:2:60', 'type' => 'number:2:60', 'explain' => false),
                'legend1'                   => 'ACP_SLIDE_WEUNI_IMAGES',
            )
        );

        // The necessary fields are defined with relation of slide_weuni_cant_img
        for($i=1;$i<=$config['slide_weuni_cant_img'];$i++)
        {
            // IMG
            $display_vars['vars']['slide_weuni_img'.$i]['lang'] = sprintf($user->lang['L_SLIDE_WEUNI_IMG'], $i);
            $display_vars['vars']['slide_weuni_img'.$i]['validate'] = 'string';
            $display_vars['vars']['slide_weuni_img'.$i]['type'] = 'text:80:255';
            $display_vars['vars']['slide_weuni_img'.$i]['explain'] = false;
            $img_ruta = (substr($config['slide_weuni_img'.$i], 0, 4) == "http") ? null : $phpbb_root_path . 'ext/Picaron/SlideWeUni/images/';
            $display_vars['vars']['slide_weuni_img'.$i]['append'] = '<br /><img src="'.(($config['slide_weuni_img'.$i]) ? $img_ruta . $config['slide_weuni_img'.$i] : '').'" style="max-width: 100%;" title ="'. $img_ruta . $config['slide_weuni_img'.$i] . '" alt="' . $user->lang['L_SLIDE_WEUNI_NO_IMG'] . $i . '"/>';
            // URL
            $display_vars['vars']['slide_weuni_url'.$i]['lang'] = sprintf($user->lang['L_SLIDE_WEUNI_URL'], $i);
            $display_vars['vars']['slide_weuni_url'.$i]['validate'] = 'string';
            $display_vars['vars']['slide_weuni_url'.$i]['type'] = 'url:80:255';
            $display_vars['vars']['slide_weuni_url'.$i]['explain'] = false;
            $display_vars['vars']['slide_weuni_url'.$i]['append'] = '<br /><br />';
        }

        if (isset($display_vars['lang']))
        {
            $user->add_lang($display_vars['lang']);
        }

        $this->new_config = $config;
        $cfg_array = (isset($_REQUEST['config'])) ? utf8_normalize_nfc($request->variable('config', array('' => ''), true)) : $this->new_config;
        $error = array();

        // We validate the complete config if whished
        validate_config_vars($display_vars['vars'], $cfg_array, $error);

        if ($submit && !check_form_key($form_key))
        {
            $error[] = $user->lang['FORM_INVALID'];
        }
        // Do not write values if there is an error
        if (sizeof($error))
        {
            $submit = false;
        }

        // We go through the display_vars to make sure no one is trying to set variables he/she is not allowed to...
        foreach ($display_vars['vars'] as $config_name => $null)
        {
            if (!isset($cfg_array[$config_name]) || strpos($config_name, 'legend') !== false)
            {
                continue;
            }

            $this->new_config[$config_name] = $config_value = $cfg_array[$config_name];

            if ($submit)
            {
                $config->set($config_name, $config_value);

            }
        }

        if ($submit)
        {
            $phpbb_log = $phpbb_container->get('log');
            $phpbb_log->add('admin', $user->data['user_id'], $user->ip, 'LOG_CONFIG_' . strtoupper($mode));

            trigger_error($user->lang['CONFIG_UPDATED'] . adm_back_link($this->u_action));
        }

        $this->tpl_name = 'acp_slideweuni';
        $this->page_title = $display_vars['title'];

        $template->assign_vars(array(
            'L_TITLE'                    => $user->lang[$display_vars['title']],
            'L_TITLE_EXPLAIN'            => $user->lang[$display_vars['title'] . '_EXPLAIN'],
            'L_ACP_SLIDE_WEUNI_VERSION'  => $user->lang['ACP_SLIDE_WEUNI_VERSION'],
            'SLIDE_WEUNI_MOD_VERSION'    => isset($config['slide_weuni_version']) ? $config['slide_weuni_version'] : false,
            'S_ERROR'                    => (sizeof($error)) ? true : false,
            'ERROR_MSG'                  => implode('<br />', $error),
            'U_ACTION'                   => $this->u_action)
        );

        // Output relevant page
        foreach ($display_vars['vars'] as $config_key => $vars)
        {
            if (!is_array($vars) && strpos($config_key, 'legend') === false)
            {
                continue;
            }

            if (strpos($config_key, 'legend') !== false)
            {
                $template->assign_block_vars('options', array(
                    'S_LEGEND'      => true,
                    'LEGEND'        => (isset($user->lang[$vars])) ? $user->lang[$vars] : $vars)
                );

                continue;
            }
            $type = explode(':', $vars['type']);

            $l_explain = '';
            if ($vars['explain'] && isset($vars['lang_explain']))
            {
                $l_explain = (isset($user->lang[$vars['lang_explain']])) ? $user->lang[$vars['lang_explain']] : $vars['lang_explain'];
            }
            else if ($vars['explain'])
            {
                $l_explain = (isset($user->lang[$vars['lang'] . '_EXPLAIN'])) ? $user->lang[$vars['lang'] . '_EXPLAIN'] : '';
            }

            $content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);

            if (empty($content))
            {
                continue;
            }

            $template->assign_block_vars('options', array(
                'KEY'           => $config_key,
                'TITLE'         => (isset($user->lang[$vars['lang']])) ? $user->lang[$vars['lang']] : $vars['lang'],
                'S_EXPLAIN'     => $vars['explain'],
                'TITLE_EXPLAIN' => $l_explain,
                'CONTENT'       => $content,
                )
            );

            unset($display_vars['vars'][$config_key]);
        }
    }
}
?>